@@ -5,7 +5,10 @@ from difflib import unified_diff
 from pathlib import Path
 from typing import Dict, List, Optional, Pattern, Tuple
 
-import rich_click as click
+try:
+    import rich_click as click
+except ImportError:
+    import click
 from robot.api import get_model
 from robot.errors import DataError
 
@@ -23,6 +26,7 @@ class Robotidy:
         src: Tuple[str, ...],
         exclude: Optional[Pattern],
         extend_exclude: Optional[Pattern],
+        skip_gitignore: bool,
         overwrite: bool,
         show_diff: bool,
         formatting_config: GlobalFormattingConfig,
@@ -33,7 +37,7 @@ class Robotidy:
         target_version: int,
         color: bool,
     ):
-        self.sources = get_paths(src, exclude, extend_exclude)
+        self.sources = get_paths(src, exclude, extend_exclude, skip_gitignore)
         self.overwrite = overwrite
         self.show_diff = show_diff
         self.check = check
